@@ -219,7 +219,7 @@ class JinjaStaticRenderer():
             html = template_object.render(
                 data=page.get_page_content(),
                 site=self.get_global_vars(),
-                meta=page.get_page_vars()
+                meta=page.get_page_vars(),
                 )
             new_file = open(new_file_path, "w")
             try: 
