@@ -71,7 +71,9 @@ class Page():
         return yaml_data
 
     def get_metadata(self, data):
-        return data["meta"]
+        if "meta" in data:
+            return data["meta"]
+        return {title: "None"}
 
     def get_content(self, data):
         content = data.copy()
@@ -92,6 +94,7 @@ class Page():
         self.file_contents = str
 
     def get_page_vars(self):
+        self.meta["slug"] = self.output_filename
         return self.meta
 
     def get_modified_time(self):
