@@ -36,7 +36,7 @@ defaults = {
 
 # Default config just loads the YAML config file
 config = {
-    'config_path':'config.json'
+    'config_path':'wrangler.json'
 }
 
 
